import argparse

from . import LogicPlum


def main():
    parser = argparse.ArgumentParser(prog='logicplum',
                                     description='LogicPlum automated machine learning.')

    parser.add_argument("--project", help="Name of the project in Logicplum AutoML.")
    parser.add_argument("--description", help="Description of the project in Logicplum AutoML.")

    parser.add_argument("--train", help="Train the data in Logicplum AutoML.")
    parser.add_argument("--target", help="Target data column in Logicplum AutoML.")

    parser.add_argument("--projectid", help="Project ID in Logicplum AutoML.")

    parser.add_argument("--score", help="Score the data from Logicplum AutoML.")

    parser.add_argument("--apikey", help="API Key to authenticate Logicplum AutoML.", required=True)

    args = parser.parse_args()

    api_key = args.apikey

    if not api_key:
        raise SystemExit("API Key required to access Logicplum AutoML.")

    if args.project:
        if not args.description:
            raise SystemExit("`--description` required to create a new project in Logicplum AutoML.")

        lp_obj = LogicPlum(api_key)
        result = lp_obj.create_project(args.project, args.description)
        print(result)

    elif args.train:
        if not args.projectid:
            raise SystemExit("`--projectid` required to train the dataset in Logicplum AutoML.")
        if not args.target:
            raise SystemExit("`--target` required to train the dataset in Logicplum AutoML.")

        lp_obj = LogicPlum(api_key)
        result = lp_obj.train(args.projectid, args.train, args.target)
        print(result)

    elif args.score:
        if not args.projectid:
            raise SystemExit("`--projectid` required to score the dataset in Logicplum AutoML.")

        lp_obj = LogicPlum(api_key)
        df = lp_obj.score(args.projectid, args.score)
        print(df)

    else:
        print("Invalid Arguments. [--project/--train/--score] required.")



import requests
import pandas as pd

from . import config


class LogicPlum:
    def __init__(self, api_key):
        self.api_key = api_key

    def create_project(self, name, description):
        url = f"{config.HOST_NAME}{config.PROJECT_CREATE}"

        headers = {
            'Authorization': self.api_key
        }

        data = {
            'name': name,
            'description': description,
        }

        response = requests.post(url, data=data, headers=headers).json()

        if 'error' in response:
            return response['error']

        return response['project_id']


    def train(self, project_id, df, target):
        url = f"{config.HOST_NAME}{config.MODEL_TRAIN}"

        headers = {
            'Authorization': self.api_key
        }

        json_df = df.to_json(orient='records')

        data = {
            'project_id': project_id,
            'target': target,
            'data': json_df,
        }

        response = requests.post(url, data=data, headers=headers).json()

        return response

    def train_status(self, project_id):
        url = f"{config.HOST_NAME}{config.MODEL_TRAIN_STATUS}"

        headers = {
            'Authorization': self.api_key
        }

        params = {
            'project_id': project_id,
        }

        response = requests.get(url, params=params, headers=headers).json()

        return response


    def score(self, deployment_id, df):
        url = f"{config.HOST_NAME}{config.MODEL_SCORE}"

        headers = {
            'Authorization': self.api_key
        }

        json_df = df.to_json(orient='records')

        data = {
            'deployment_id': deployment_id,
            'data': json_df,
        }

        response = requests.post(url, data=data, headers=headers).json()
        if 'error' in response:
            return response['error']

        return pd.read_json(response['prediction'], orient='records')



import setuptools

with open('requirements.txt') as f:
    requirements = f.readlines()

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="logicplum",
    version="0.1.3",
    author="LogicPlum",
    author_email="message@logicplum.com",
    description="This client library is designed to support the LogicPlum API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/LogicPlum/logicplum_v2",
    license='MIT',
    packages=setuptools.find_packages(),
    entry_points={
            'console_scripts': [
                'logicplum = logicplum.logicplum:main'
            ]
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        # "Operating System :: Developers/Data Scientists",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    keywords='logicplum machine-learning AI automl prediction model',
    install_requires=requirements,
    python_requires='>=3.6',
)



# HOST_NAME = "http://127.0.0.1:8000/"
# HOST_NAME = "https://sb-api.logicplum.com/"
HOST_NAME = "https://staging.logicplum.com/"

PROJECT_CREATE = "api/v2/external/create-project"
MODEL_TRAIN = "api/v2/external/train"
MODEL_TRAIN_STATUS = "api/v2/external/train/status"
MODEL_SCORE = "api/v2/external/score"
